/*
 * Copyright 2012, 2014 Peter Olsson
 * 
 * This file is part of Brum Brum Rally.
 * 
 * Brum Brum Rally is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Brum Brum Rally is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef TILESET_H
#define TILESET_H

#include "Surface.h"
#include <vector>

class Map;

class TileSet
{
public:
	
	TileSet(const std::string& name, const Surface& surface);
	void decorate(const Map& map, Surface& background) const;
	void decorateUpper(const Map& map, Surface& background) const;
	void decorateLower(const Map& map, Surface& background) const;
	const std::string& getName() const;
	int getGfxTileLimit() const;
	
	static const std::vector<std::string>& getTileSetNames();
	static const std::vector<TileSet>& getTileSets();
	static const TileSet& getTileSet(const std::string& name);
	static const TileSet& getRandomTileSet();
	
private:
	const Surface& pickTile(const Map& map, int x, int y) const;
	const Surface& getTile(int i) const;
	TileSet(){}
	
	std::vector<Surface> tiles;
	Uint32 wallColor;
	std::string name;
};

#endif
